@@ -71,10 +71,13 @@ def server_redis(card='eth0', size=None, newer='remi'):
 
     with settings(warn_only=True):
         run('mkdir -p /storage/redis')
+        run('useradd redis -r -s /sbin/nologin ')
+        cmd_useradd('redis','/sbin/nologin')
+
 
     yum_install('redis', newer='remi')
 
-    run('chown redis /storage/redis')
+    run('chown redis.redis /storage/redis')
     run('chkconfig --level 35 redis on')
 
     ip = cmd_ip(card)
